==> jc-1.4.0.tar.gz: polyglot/util/Assert.h <==
// public final class polyglot.util.Assert

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class efec7008a68aabbf polyglot_util_Assert

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Assert_H_
#define _JC_polyglot_util_Assert_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_Assert$sub_refs	_jc_polyglot_util_Assert$sub_refs;
typedef struct _jc_polyglot_util_Assert$sub_nonrefs	_jc_polyglot_util_Assert$sub_nonrefs;
typedef struct _jc_polyglot_util_Assert$refs	_jc_polyglot_util_Assert$refs;
typedef struct _jc_polyglot_util_Assert$nonrefs	_jc_polyglot_util_Assert$nonrefs;
typedef struct _jc_polyglot_util_Assert$object	_jc_polyglot_util_Assert$object;

typedef const struct _jc_polyglot_util_Assert$vmethods	_jc_polyglot_util_Assert$vmethods;
typedef const struct _jc_polyglot_util_Assert$vtable	_jc_polyglot_util_Assert$vtable;
typedef const struct _jc_polyglot_util_Assert$vtype	_jc_polyglot_util_Assert$vtype;

// Constructors
extern void _jc_polyglot_util_Assert$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Assert$object *);

// Static methods
extern void _jc_polyglot_util_Assert$method$check$0c1051f307f8b787(_jc_env *, struct _jc_java_lang_String$object *, jboolean);
extern void _jc_polyglot_util_Assert$method$check$e072849056168b94(_jc_env *, jboolean);

// Virtual methods structure
struct _jc_polyglot_util_Assert$vmethods {
};

// Vtable
struct _jc_polyglot_util_Assert$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Assert$vmethods	polyglot_util_Assert;
};

// Vtype
struct _jc_polyglot_util_Assert$vtype {
	_jc_type			type;
	_jc_polyglot_util_Assert$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Assert$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Assert$refs {
    _jc_polyglot_util_Assert$sub_refs	polyglot_util_Assert;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Assert$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Assert$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Assert$sub_nonrefs	polyglot_util_Assert;
};

// Object instance structure
struct _jc_polyglot_util_Assert$object {
	_jc_polyglot_util_Assert$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Assert$vtype	*vtype;
	_jc_polyglot_util_Assert$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Assert$vtype _jc_polyglot_util_Assert$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Assert, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Assert$class_object;

#endif	/* _JC_polyglot_util_Assert_H_ */

==> jc-1.4.6.tar.gz: polyglot/util/Assert.h <==
// public final class polyglot.util.Assert

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class efec7008a68aabbf polyglot_util_Assert

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_polyglot_util_Assert_H_
#define _JC_polyglot_util_Assert_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_polyglot_util_Assert$sub_refs	_jc_polyglot_util_Assert$sub_refs;
typedef struct _jc_polyglot_util_Assert$sub_nonrefs	_jc_polyglot_util_Assert$sub_nonrefs;
typedef struct _jc_polyglot_util_Assert$refs	_jc_polyglot_util_Assert$refs;
typedef struct _jc_polyglot_util_Assert$nonrefs	_jc_polyglot_util_Assert$nonrefs;
typedef struct _jc_polyglot_util_Assert$object	_jc_polyglot_util_Assert$object;

typedef const struct _jc_polyglot_util_Assert$vmethods	_jc_polyglot_util_Assert$vmethods;
typedef const struct _jc_polyglot_util_Assert$vtable	_jc_polyglot_util_Assert$vtable;
typedef const struct _jc_polyglot_util_Assert$vtype	_jc_polyglot_util_Assert$vtype;

// Constructors
extern void _jc_polyglot_util_Assert$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_util_Assert$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_polyglot_util_Assert$method$check$0c1051f307f8b787(_jc_env *, struct _jc_java_lang_String$object *, jboolean) _JC_JCNI_ATTR;
extern void _jc_polyglot_util_Assert$method$check$e072849056168b94(_jc_env *, jboolean) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_util_Assert$vmethods {
};

// Vtable
struct _jc_polyglot_util_Assert$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_util_Assert$vmethods	polyglot_util_Assert;
};

// Vtype
struct _jc_polyglot_util_Assert$vtype {
	_jc_type			type;
	_jc_polyglot_util_Assert$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_util_Assert$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_util_Assert$refs {
    _jc_polyglot_util_Assert$sub_refs	polyglot_util_Assert;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_util_Assert$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_util_Assert$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_util_Assert$sub_nonrefs	polyglot_util_Assert;
};

// Object instance structure
struct _jc_polyglot_util_Assert$object {
	_jc_polyglot_util_Assert$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_util_Assert$vtype	*vtype;
	_jc_polyglot_util_Assert$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_util_Assert$vtype _jc_polyglot_util_Assert$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_util_Assert, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_util_Assert$class_object;

#endif	/* _JC_polyglot_util_Assert_H_ */
